@@ -1,5 +1,6 @@
 import logging
 import httpx
+import re
 
 from typing import Dict, Optional, TypedDict, overload
 from typing_extensions import Unpack
@@ -10,10 +11,14 @@ from agentbox.envd.api import ENVD_API_HEALTH_ROUTE, ahandle_envd_api_exception
 from agentbox.exceptions import format_request_timeout_error
 from agentbox.sandbox.main import SandboxSetup
 from agentbox.sandbox.utils import class_method_variant
+from agentbox.sandbox_async.adb_shell.adb_shell import ADBShell
 from agentbox.sandbox_async.filesystem.filesystem import Filesystem
 from agentbox.sandbox_async.commands.command import Commands
 from agentbox.sandbox_async.commands.pty import Pty
 from agentbox.sandbox_async.sandbox_api import SandboxApi, SandboxInfo
+from agentbox.api.client.models import SandboxADB
+from agentbox.sandbox_async.filesystem_ssh.filesystem_ssh import SSHFilesystem
+from agentbox.sandbox_async.commands_ssh.command_ssh import SSHCommands
 
 logger = logging.getLogger(__name__)
 
@@ -35,6 +40,14 @@ class AsyncSandboxOpts(TypedDict):
     envd_version: Optional[str]
     envd_access_token: Optional[str]
     connection_config: ConnectionConfig
+    ssh_host: str
+    ssh_port: int
+    ssh_username: str
+    ssh_password: str
+    adb_auth_command: str
+    adb_auth_password: str
+    adb_connect_command: str
+    adb_forwarder_command: str
 
 
 class AsyncSandbox(SandboxSetup, SandboxApi):
@@ -48,7 +61,7 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
     - Run isolated code
     - Access the internet
 
-    Check docs [here](https://agentbox.cloud/docs).
+    Check docs [here](https://agentbox.lingyiwanwu.net/docs).
 
     Use the `AsyncSandbox.create()` to create a new sandbox.
 
@@ -92,6 +105,13 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
     def envd_api_url(self) -> str:
         return self._envd_api_url
 
+    @property
+    def adb_shell(self) -> ADBShell:
+        """
+        Module for adb shell in the sandbox.
+        """
+        return self._adb_shell
+
     @property
     def _envd_access_token(self) -> str:
         """Private property to access the envd token"""
@@ -114,37 +134,77 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
 
         self._sandbox_id = opts["sandbox_id"]
         self._connection_config = opts["connection_config"]
+        self._ssh_host = opts["ssh_host"]
+        self._ssh_port = opts["ssh_port"]
+        self._ssh_username = opts["ssh_username"]
+        self._ssh_password = opts["ssh_password"]
+        self._adb_auth_command = opts["adb_auth_command"]
+        self._adb_auth_password = opts["adb_auth_password"]
+        self._adb_connect_command = opts["adb_connect_command"]
+        self._adb_forwarder_command = opts["adb_forwarder_command"]
 
         self._envd_api_url = f"{'http' if self.connection_config.debug else 'https'}://{self.get_host(self.envd_port)}"
         self._envd_version = opts["envd_version"]
         self._envd_access_token = opts["envd_access_token"]
 
-        self._transport = AsyncTransportWithLogger(
-            limits=self._limits, proxy=self._connection_config.proxy
-        )
-        self._envd_api = httpx.AsyncClient(
-            base_url=self.envd_api_url,
-            transport=self._transport,
-            headers=self._connection_config.headers,
-        )
+        # 根据 sandbox id 进行区分 commands 类型
+        if "brd" in self._sandbox_id.lower():
+            self._commands = SSHCommands(
+                self._ssh_host,
+                self._ssh_port,
+                self._ssh_username,
+                self._ssh_password,
+                self.connection_config,
+            )
+            self._watch_commands = SSHCommands(
+                self._ssh_host,
+                self._ssh_port,
+                self._ssh_username,
+                self._ssh_password,
+                self.connection_config,
+            )
+            self._filesystem = SSHFilesystem(
+                self._ssh_host,
+                self._ssh_port,
+                self._ssh_username,
+                self._ssh_password,
+                self.connection_config,
+                self._commands,
+                self._watch_commands,
+            )
+            self._adb_shell = ADBShell(
+                forwarder_command= self._adb_forwarder_command,
+                connect_command = self._adb_connect_command,
+                adb_auth_command = self._adb_auth_command,
+                adb_auth_password = self._adb_auth_password
+            )
+        else:
+            self._transport = AsyncTransportWithLogger(
+                limits=self._limits, proxy=self._connection_config.proxy
+            )
+            self._envd_api = httpx.AsyncClient(
+                base_url=self.envd_api_url,
+                transport=self._transport,
+                headers=self._connection_config.headers,
+            )
 
-        self._filesystem = Filesystem(
-            self.envd_api_url,
-            self._envd_version,
-            self.connection_config,
-            self._transport._pool,
-            self._envd_api,
-        )
-        self._commands = Commands(
-            self.envd_api_url,
-            self.connection_config,
-            self._transport._pool,
-        )
-        self._pty = Pty(
-            self.envd_api_url,
-            self.connection_config,
-            self._transport._pool,
-        )
+            self._filesystem = Filesystem(
+                self.envd_api_url,
+                self._envd_version,
+                self.connection_config,
+                self._transport._pool,
+                self._envd_api,
+            )
+            self._commands = Commands(
+                self.envd_api_url,
+                self.connection_config,
+                self._transport._pool,
+            )
+            self._pty = Pty(
+                self.envd_api_url,
+                self.connection_config,
+                self._transport._pool,
+            )
 
     async def is_running(self, request_timeout: Optional[float] = None) -> bool:
         """
@@ -221,6 +281,18 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
             sandbox_id = "debug_sandbox_id"
             envd_version = None
             envd_access_token = None
+            ssh_host = "127.0.0.1"
+            ssh_port = 22
+            ssh_username = "debug"
+            ssh_password = "debug"
+            adb_info = SandboxADB(
+                adb_auth_command="adb shell",
+                auth_password="debug",
+                connect_command="adb connect 127.0.0.1",
+                expire_time="",
+                forwarder_command="",
+                instance_no="debug_sandbox_id"
+            )
         else:
             response = await SandboxApi._create_sandbox(
                 template=template or cls.default_template,
@@ -244,6 +316,34 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
             ):
                 connection_headers["X-Access-Token"] = envd_access_token
 
+            # Get SSH connection details
+            ssh_info = await SandboxApi._get_ssh(
+                sandbox_id=sandbox_id,
+                api_key=api_key,
+                domain=domain,
+                debug=debug,
+                request_timeout=request_timeout,
+                proxy=proxy,
+            )
+
+            # Parse SSH connection details from the connect command
+            pattern = r'ssh\s+-p\s+(\d+).*?\s+([^@\s]+)@([\w\.-]+)'
+            ssh_match = re.search(pattern, ssh_info.connect_command)
+            if ssh_match:
+                ssh_port = int(ssh_match.group(1))
+                ssh_username = ssh_match.group(2)
+                ssh_host = ssh_match.group(3)
+                ssh_password = ssh_info.auth_password
+            else:
+                raise Exception("Could not parse SSH connection details")
+            # Get adb connection details
+            adb_info = await SandboxApi._get_adb(
+                sandbox_id=sandbox_id,
+                api_key=api_key,
+                domain=domain,
+                debug=debug,
+                proxy=proxy,
+            )
         connection_config = ConnectionConfig(
             api_key=api_key,
             domain=domain,
@@ -258,6 +358,14 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
             envd_version=envd_version,
             envd_access_token=envd_access_token,
             connection_config=connection_config,
+            ssh_host=ssh_host,
+            ssh_port=ssh_port,
+            ssh_username=ssh_username,
+            ssh_password=ssh_password,
+            adb_auth_command=adb_info.adb_auth_command,
+            adb_auth_password=adb_info.auth_password,
+            adb_connect_command=adb_info.connect_command,
+            adb_forwarder_command=adb_info.forwarder_command
         )
 
     @classmethod
@@ -290,7 +398,7 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
 
         connection_headers = {}
 
-        response = await SandboxApi.get_info(sandbox_id)
+        response = await SandboxApi.get_info(sandbox_id=sandbox_id, api_key=api_key, domain=domain, debug=debug)
 
         if response._envd_access_token is not None and not isinstance(
             response._envd_access_token, Unset
@@ -305,11 +413,47 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
             proxy=proxy,
         )
 
+        # Get SSH connection details
+        ssh_info = await SandboxApi._get_ssh(
+            sandbox_id=sandbox_id,
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            proxy=proxy,
+        )
+
+        # Parse SSH connection details from the connect command
+        pattern = r'ssh\s+-p\s+(\d+).*?\s+([^@\s]+)@([\w\.-]+)'
+        ssh_match = re.search(pattern, ssh_info.connect_command)
+        if ssh_match:
+            ssh_port = int(ssh_match.group(1))
+            ssh_username = ssh_match.group(2)
+            ssh_host = ssh_match.group(3)
+            ssh_password = ssh_info.auth_password
+        else:
+            raise Exception("Could not parse SSH connection details")
+
+        # Get adb connection details
+        adb_info = await SandboxApi._get_adb(
+            sandbox_id=sandbox_id,
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            proxy=proxy,
+        )
         return cls(
             sandbox_id=sandbox_id,
             connection_config=connection_config,
             envd_version=response.envd_version,
             envd_access_token=response._envd_access_token,
+            ssh_host=ssh_host,
+            ssh_port=ssh_port,
+            ssh_username=ssh_username,
+            ssh_password=ssh_password,
+            adb_auth_command=adb_info.adb_auth_command,
+            adb_auth_password=adb_info.auth_password,
+            adb_connect_command=adb_info.connect_command,
+            adb_forwarder_command=adb_info.forwarder_command
         )
 
     async def __aenter__(self):
