@@ -4,12 +4,14 @@ import re
 
 from typing import Dict, Optional, overload
 
+from agentbox.api.client.models import SandboxADB
 from agentbox.api.client.types import Unset
 from agentbox.connection_config import ConnectionConfig, ProxyTypes
 from agentbox.envd.api import ENVD_API_HEALTH_ROUTE, handle_envd_api_exception
 from agentbox.exceptions import SandboxException, format_request_timeout_error
 from agentbox.sandbox.main import SandboxSetup
 from agentbox.sandbox.utils import class_method_variant
+from agentbox.sandbox_sync.adb_shell.adb_shell import ADBShell
 from agentbox.sandbox_sync.filesystem.filesystem import Filesystem
 from agentbox.sandbox_sync.commands.command import Commands
 from agentbox.sandbox_sync.commands.pty import Pty
@@ -69,6 +71,13 @@ class Sandbox(SandboxSetup, SandboxApi):
         """
         return self._commands
 
+    @property
+    def adb_shell(self) -> ADBShell:
+        """
+        Module for adb shell in the sandbox.
+        """
+        return self._adb_shell
+
     @property
     def pty(self) -> Pty:
         """
@@ -144,6 +153,18 @@ class Sandbox(SandboxSetup, SandboxApi):
             self._sandbox_id = "debug_sandbox_id"
             self._envd_version = None
             self._envd_access_token = None
+            self._ssh_host = "127.0.0.1"
+            self._ssh_port = 22
+            self._ssh_username = "debug"
+            self._ssh_password = "debug"
+            self._adb_info = SandboxADB(
+                adb_auth_command="adb shell",
+                auth_password="debug",
+                connect_command="adb connect 127.0.0.1",
+                expire_time="",
+                forwarder_command="",
+                instance_no="debug_sandbox_id"
+            )
         elif sandbox_id is not None:
             response = SandboxApi.get_info(sandbox_id=sandbox_id, api_key=api_key, domain=domain)
 
@@ -176,6 +197,14 @@ class Sandbox(SandboxSetup, SandboxApi):
                 self._ssh_password = ssh_info.auth_password
             else:
                 raise Exception("Could not parse SSH connection details")
+            # Get adb connection details
+            self._adb_info = SandboxApi._get_adb(
+                sandbox_id=self._sandbox_id,
+                api_key=api_key,
+                domain=domain,
+                debug=debug,
+                proxy=proxy,
+            )
         else:
             template = template or self.default_template
             timeout = timeout or self.default_sandbox_timeout
@@ -222,7 +251,14 @@ class Sandbox(SandboxSetup, SandboxApi):
                 self._ssh_password = ssh_info.auth_password
             else:
                 raise Exception("Could not parse SSH connection details")
-
+            # Get adb connection details
+            self._adb_info = SandboxApi._get_adb(
+                sandbox_id=self._sandbox_id,
+                api_key=api_key,
+                domain=domain,
+                debug=debug,
+                proxy=proxy,
+            )
         self._transport = TransportWithLogger(limits=self._limits, proxy=proxy)
         self._connection_config = ConnectionConfig(
             api_key=api_key,
@@ -258,6 +294,12 @@ class Sandbox(SandboxSetup, SandboxApi):
                 self._commands,
                 self._watch_commands,
             )
+            self._adb_shell = ADBShell(
+                forwarder_command=self._adb_info.forwarder_command,
+                connect_command=self._adb_info.connect_command,
+                adb_auth_command=self._adb_info.adb_auth_command,
+                adb_auth_password=self._adb_info.auth_password,
+            )
         else:  
             self._envd_api_url = f"{'http' if self.connection_config.debug else 'https'}://{self.get_host(self.envd_port)}"
             self._envd_api = httpx.Client(
